module Debate.Arguments.Nutrition.SaturatedFatLDL exposing (..)

import Debate.Types exposing (..)


argumentSaturatedFatLDL : Argument
argumentSaturatedFatLDL =
    { argumentTitle = "Argument For Atherogenic Coconut Oil"
    , propositionTitle = "There is not a reason to believe that coconut oil is any better for heart health than other saturated fat sources that increase LDL-C."
    , propositionSummary = "Summary"
    , proofLink = "https://www.umsu.de/trees/#(~6x(Sx~1Lx~5~3Rx)),(Sc),(Lc)%7C=(~3Rc)"
    , definitionTable =
        [ { definiendum = "S"
          , definiens = "a given (x) increases LDL-C at a similar rate to other saturated fat sources"
          }
        , { definiendum = "L"
          , definiens = "a given (x) has no other known qualities that counteract said increase in LDL-C"
          }
        , { definiendum = "R"
          , definiens = "there is a reason to believe that such an (x) is any better for heart health than other (x) that increase LDL-C"
          }
        , { definiendum = "c"
          , definiens = "coconut oil"
          }
        ]
    , argumentFormalization =
        [ { premises =
                [ { premise = "If a given saturated fat source increases LDL-C at a similar rate to other saturated fat sources and and a given saturated fat source has no other known qualities that counteract said increase in LDL-C, then there is not a reason to believe that such a saturated fat source is any better for heart health than other saturated fat sources that increase LDL-C."
                  , notation = "(∀x(Sx∧Lx→¬Rx))"
                  }
                , { premise = "Coconut oil increases LDL-C at a similar rate to other saturated fat sources."
                  , notation = "(Sc)"
                  }
                , { premise = "Coconut oil has no other known qualities that counteract said increase in LDL-C."
                  , notation = "(Lc)"
                  }
                ]
          , conclusion = "Therefore, there is not a reason to believe that coconut oil is any better for heart health than other saturated fat sources that increase LDL-C."
          , conclusionNotation = "(∴¬Rc)"
          }
        ]
    }
